summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoDocument.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoDocument.h')
-rw-r--r--lib/kofficecore/KoDocument.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/kofficecore/KoDocument.h b/lib/kofficecore/KoDocument.h
index 0499ab6c..4051cca6 100644
--- a/lib/kofficecore/KoDocument.h
+++ b/lib/kofficecore/KoDocument.h
@@ -71,7 +71,7 @@ public:
* Constructor.
* The first 4 arguments are the same as the ones passed to KParts::Factory::createPart.
*
* @param tqparentWidget the tqparent widget, in case we create a wrapper widget
* (in single view mode).
* Usually the first argument passed by KParts::Factory::createPart.
* @param widgetName name of the widget.
@@ -81,12 +81,12 @@ public:
* pass a meaningful name here which matches the pattern [A-Za-z_][A-Za-z_0-9]*.
* @param singleViewMode determines whether the document may only have one view. In this case
* the @p tqparent must be a TQWidget derived class. KoDocument will then create a wrapper widget
* (KoViewWrapperWidget) which is a child of @p tqparentWidget.
* This widget can be retrieved by calling widget().
*
* @todo explain what the purpose of widgetName is.
*/
- KoDocument( TQWidget* tqparentWidget,
+ KoDocument( TQWidget* parentWidget,
const char* widgetName,
TQObject* tqparent,
const char* name,
@@ -459,9 +459,9 @@ public:
* Initializes an empty document (display the template dialog!).
* You have to overload this method to initialize all your document variables.
* @param flags see InitDocFlags
* @param tqparentWidget the widget this document belongs with
*/
- virtual bool initDoc(InitDocFlags flags, TQWidget* tqparentWidget=0) = 0;
+ virtual bool initDoc(InitDocFlags flags, TQWidget* parentWidget=0) = 0;
/**
* Creates and shows the start up widget.
@@ -798,12 +798,12 @@ public:
/**
* Indicates that this document is currently viewed
* and thus should control the title caption.
- * Also resets current flag for all tqparents.
+ * Also resets current flag for all parents.
*/
void setCurrent( bool on = true );
/**
- * Sets current flag for this document and all its tqparents
+ * Sets current flag for this document and all its parents
*/
void forceCurrent( bool on );
bool isCurrent() const;
@@ -71,7 +71,7 @@ public:
* The first 4 arguments are the same as the ones passed to KParts::Factory::createPart.
*
- * @param tqparentWidget the tqparent widget, in case we create a wrapper widget
+ * @param parentWidget the tqparent widget, in case we create a wrapper widget
* (in single view mode).
* Usually the first argument passed by KParts::Factory::createPart.
@@ -81,12 +81,12 @@ public:
* @param singleViewMode determines whether the document may only have one view. In this case
* the @p tqparent must be a TQWidget derived class. KoDocument will then create a wrapper widget
- * (KoViewWrapperWidget) which is a child of @p tqparentWidget.
+ * (KoViewWrapperWidget) which is a child of @p parentWidget.
* This widget can be retrieved by calling widget().
*
@@ -459,9 +459,9 @@ public:
* You have to overload this method to initialize all your document variables.
* @param flags see InitDocFlags
- * @param tqparentWidget the widget this document belongs with
+ * @param parentWidget the widget this document belongs with
*/